Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1592)

Unified Diff: content/public/test/test_mojo_app.h

Issue 1832813002: Add mojom module suffix in .mojom files in content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address Tom's comment Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/permission_status.mojom ('k') | content/public/test/test_mojo_app.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/test/test_mojo_app.h
diff --git a/content/public/test/test_mojo_app.h b/content/public/test/test_mojo_app.h
index be8c902c77822d27147d925f918a298ba05677d5..01824ad9709e7b28c87c31cd5d68b73a35e5ef03 100644
--- a/content/public/test/test_mojo_app.h
+++ b/content/public/test/test_mojo_app.h
@@ -15,11 +15,11 @@ namespace content {
extern const char kTestMojoAppUrl[];
// Simple Mojo app which provides a TestMojoService impl. The app terminates
// itself after its TestService fulfills a single DoSomething call.
class TestMojoApp : public mojo::ShellClient,
- public mojo::InterfaceFactory<TestMojoService>,
- public TestMojoService {
+ public mojo::InterfaceFactory<mojom::TestMojoService>,
+ public mojom::TestMojoService {
public:
TestMojoApp();
~TestMojoApp() override;
@@ -28,15 +28,15 @@ class TestMojoApp : public mojo::ShellClient,
// mojo::ShellClient:
bool AcceptConnection(mojo::Connection* connection) override;
- // mojo::InterfaceFactory<TestMojoService>:
+ // mojo::InterfaceFactory<mojom::TestMojoService>:
void Create(mojo::Connection* connection,
- mojo::InterfaceRequest<TestMojoService> request) override;
+ mojo::InterfaceRequest<mojom::TestMojoService> request) override;
// TestMojoService:
void DoSomething(const DoSomethingCallback& callback) override;
void GetRequestorName(const GetRequestorNameCallback& callback) override;
- mojo::Binding<TestMojoService> service_binding_;
+ mojo::Binding<mojom::TestMojoService> service_binding_;
// The name of the app connecting to us.
std::string requestor_name_;
« no previous file with comments | « content/public/common/permission_status.mojom ('k') | content/public/test/test_mojo_app.cc » ('j') | no next file with comments »
@@ -15,11 +15,11 @@ namespace content {
extern const char kTestMojoAppUrl[];
-// Simple Mojo app which provides a TestMojoService impl. The app terminates
-// itself after its TestService fulfills a single DoSomething call.
+// Simple Mojo app which provides a mojom::TestMojoService impl. The app
+// terminates itself after its TestService fulfills a single DoSomething call.
class TestMojoApp : public mojo::ShellClient,

Powered by Google App Engine
This is Rietveld 408576698